@@ -1,6 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2020 The Music Player Daemon Project
- * Project homepage: http://musicpd.org
+ * Copyright 2004-2021 The Music Player Daemon Project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -158,6 +157,9 @@ static constexpr HelpRow help_text[] = {
 	{ Command::PLAY, N_("Enter directory/Select and play song") },
 	Command::SELECT,
 	Command::ADD,
+#ifdef ENABLE_PLAYLIST_EDITOR
+	Command::EDIT,
+#endif
 	Command::SAVE_PLAYLIST,
 	{ Command::DELETE, N_("Delete playlist") },
 	Command::GO_PARENT_DIRECTORY,
