@@ -1,6 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2020 The Music Player Daemon Project
- * Project homepage: http://musicpd.org
+ * Copyright 2004-2021 The Music Player Daemon Project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,14 +57,22 @@ struct tag_label {
 	const char *label;
 };
 
+/* note: add all tags mentioned here to #global_tag_whitelist in
+   Instance.cxx */
 static constexpr struct tag_label tag_labels[] = {
 	{ MPD_TAG_ARTIST, N_("Artist") },
 	{ MPD_TAG_TITLE, N_("Title") },
 	{ MPD_TAG_ALBUM, N_("Album") },
+#if LIBMPDCLIENT_CHECK_VERSION(2,17,0)
+	{ MPD_TAG_WORK, N_("Work") },
+#endif
 	{ LABEL_LENGTH, N_("Length") },
 	{ LABEL_POSITION, N_("Position") },
 	{ MPD_TAG_COMPOSER, N_("Composer") },
 	{ MPD_TAG_PERFORMER, N_("Performer") },
+#if LIBMPDCLIENT_CHECK_VERSION(2,17,0)
+	{ MPD_TAG_CONDUCTOR, N_("Conductor") },
+#endif
 	{ MPD_TAG_NAME, N_("Name") },
 	{ MPD_TAG_DISC, N_("Disc") },
 	{ MPD_TAG_TRACK, N_("Track") },
